@@ -1,22 +1,8 @@
-/***************************************************************************
- *   This file is part of KDevelop                                         *
- *   Copyright 2010-2012 Milian Wolff <mail@milianw.de>                    *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU Library General Public License as       *
- *   published by the Free Software Foundation; either version 2 of the    *
- *   License, or (at your option) any later version.                       *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU Library General Public     *
- *   License along with this program; if not, write to the                 *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2010-2012 Milian Wolff <mail@milianw.de>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "abstractfilemanagerplugin.h"
 
@@ -84,7 +70,7 @@ public:
      * The just returned must be started in one way or another for this method
      * to have any affect. The job will then auto-delete itself upon completion.
      */
-    Q_REQUIRED_RESULT KIO::Job* eventuallyReadFolder(ProjectFolderItem* item);
+    [[nodiscard]] KJob* eventuallyReadFolder(ProjectFolderItem* item);
     void addJobItems(FileManagerListJob* job,
                      ProjectFolderItem* baseItem,
                      const KIO::UDSEntryList& entries);
@@ -116,7 +102,7 @@ void AbstractFileManagerPluginPrivate::projectClosing(IProject* project)
         // see also addLotsOfFiles test
         for (FileManagerListJob* job : *projectJobIt) {
             qCDebug(FILEMANAGER) << "killing project job:" << job;
-            job->abort();
+            job->kill();
         }
         m_projectJobs.remove(project);
     }
@@ -135,7 +121,7 @@ void AbstractFileManagerPluginPrivate::projectClosing(IProject* project)
     m_filters.remove(project);
 }
 
-KIO::Job* AbstractFileManagerPluginPrivate::eventuallyReadFolder(ProjectFolderItem* item)
+KJob* AbstractFileManagerPluginPrivate::eventuallyReadFolder(ProjectFolderItem* item)
 {
     auto* listJob = new FileManagerListJob( item );
     m_projectJobs[ item->project() ] << listJob;
@@ -634,7 +620,7 @@ bool AbstractFileManagerPlugin::moveFilesAndFolders(const QList< ProjectBaseItem
                 emit folderRemoved(item->folder());
             }
             delete item;
-            KIO::Job *readJob = d->eventuallyReadFolder(newParent);
+            auto* const readJob = d->eventuallyReadFolder(newParent);
             // reload first level synchronously, deeper levels will run async
             // this is required for code that expects the new item to exist after
             // this method finished
@@ -659,7 +645,7 @@ bool AbstractFileManagerPlugin::copyFilesAndFolders(const Path::List& items, Pro
 
         success &= copyUrl(newParent->project(), item.toUrl(), newParent->path().toUrl());
         if ( success ) {
-            KIO::Job *readJob = d->eventuallyReadFolder(newParent);
+            auto* const readJob = d->eventuallyReadFolder(newParent);
             // reload first level synchronously, deeper levels will run async
             // this is required for code that expects the new item to exist after
             // this method finished
